==> ores-0.1.0.zip: ores-0.1.0/ores/feature_lists/enwiki.py <==
from revscoring.features import (diff, page, parent_revision,
                                 previous_user_revision, revision, user)
from revscoring.features.modifiers import log

from . import generic

damaging = [
    log(diff.added_symbolic_chars_ratio + 1),
    log(diff.chars_added + 1),
    log(diff.chars_removed + 1),
    diff.longest_repeated_char_added,
    diff.longest_token_added,
    log(diff.markup_chars_added + 1),
    log(diff.markup_chars_removed + 1),
    log(diff.numeric_chars_added + 1),
    log(diff.numeric_chars_removed + 1),
    diff.proportion_of_chars_added,
    diff.proportion_of_chars_removed,
    diff.proportion_of_markup_chars_added,
    diff.proportion_of_numeric_chars_added,
    diff.proportion_of_symbolic_chars_added,
    diff.proportion_of_uppercase_chars_added,
    log(diff.segments_added + 1),
    log(diff.segments_removed + 1),
    log(diff.symbolic_chars_added + 1),
    log(diff.symbolic_chars_removed + 1),
    log(diff.uppercase_chars_added + 1),
    log(diff.uppercase_chars_removed + 1),
    log(diff.words_added + 1),
    log(diff.words_removed + 1),
    diff.bytes_changed + 1,
    diff.bytes_changed_ratio,
    page.is_content_namespace,
    parent_revision.was_same_user,
    log(parent_revision.words + 1),
    log(user.age + 1),
    user.is_anon,
    user.is_bot,
    log(diff.added_badwords_ratio + 1),
    log(diff.added_misspellings_ratio + 1),
    log(diff.badwords_added + 1),
    log(diff.badwords_removed + 1),
    log(diff.misspellings_added + 1),
    log(diff.misspellings_removed + 1),
    diff.proportion_of_badwords_added,
    diff.proportion_of_badwords_removed,
    diff.proportion_of_misspellings_added,
    diff.proportion_of_misspellings_removed
]

good_faith = generic.good_faith + [
    log(diff.added_badwords_ratio + 1),
    log(diff.added_misspellings_ratio + 1),
    log(diff.badwords_added + 1),
    log(diff.badwords_removed + 1),
    log(diff.misspellings_added + 1),
    log(diff.misspellings_removed + 1),
    diff.proportion_of_badwords_added,
    diff.proportion_of_badwords_removed,
    diff.proportion_of_misspellings_added,
    diff.proportion_of_misspellings_removed,
    log(diff.removed_badwords_ratio + 1),
    log(diff.removed_misspellings_ratio + 1),
    log(parent_revision.badwords + 1),
    log(parent_revision.misspellings + 1),
    log(parent_revision.proportion_of_badwords + 1),
    log(parent_revision.proportion_of_misspellings + 1),
    log(revision.badwords + 1),
    log(revision.misspellings + 1),
    log(revision.proportion_of_badwords + 1),
    log(revision.proportion_of_misspellings + 1)
]

==> ores-0.2.0.zip: ores-0.2.0/ores/feature_lists/enwiki.py <==
from revscoring.features import diff, page, parent_revision, revision, user
from revscoring.features.modifiers import log

from . import generic

damaging = [
    log(diff.added_symbolic_chars_ratio + 1),
    log(diff.chars_added + 1),
    log(diff.chars_removed + 1),
    diff.longest_repeated_char_added,
    diff.longest_token_added,
    log(diff.markup_chars_added + 1),
    log(diff.markup_chars_removed + 1),
    log(diff.numeric_chars_added + 1),
    log(diff.numeric_chars_removed + 1),
    diff.proportion_of_chars_added,
    diff.proportion_of_chars_removed,
    diff.proportion_of_markup_chars_added,
    diff.proportion_of_numeric_chars_added,
    diff.proportion_of_symbolic_chars_added,
    diff.proportion_of_uppercase_chars_added,
    log(diff.segments_added + 1),
    log(diff.segments_removed + 1),
    log(diff.symbolic_chars_added + 1),
    log(diff.symbolic_chars_removed + 1),
    log(diff.uppercase_chars_added + 1),
    log(diff.uppercase_chars_removed + 1),
    log(diff.words_added + 1),
    log(diff.words_removed + 1),
    diff.bytes_changed + 1,
    diff.bytes_changed_ratio,
    page.is_content_namespace,
    parent_revision.was_same_user,
    log(parent_revision.words + 1),
    log(user.age + 1),
    user.is_anon,
    user.is_bot,
    log(diff.added_badwords_ratio + 1),
    log(diff.added_misspellings_ratio + 1),
    log(diff.badwords_added + 1),
    log(diff.badwords_removed + 1),
    log(diff.misspellings_added + 1),
    log(diff.misspellings_removed + 1),
    diff.proportion_of_badwords_added,
    diff.proportion_of_badwords_removed,
    diff.proportion_of_misspellings_added,
    diff.proportion_of_misspellings_removed
]

good_faith = generic.good_faith + [
    log(diff.added_badwords_ratio + 1),
    log(diff.added_misspellings_ratio + 1),
    log(diff.badwords_added + 1),
    log(diff.badwords_removed + 1),
    log(diff.misspellings_added + 1),
    log(diff.misspellings_removed + 1),
    diff.proportion_of_badwords_added,
    diff.proportion_of_badwords_removed,
    diff.proportion_of_misspellings_added,
    diff.proportion_of_misspellings_removed,
    log(diff.removed_badwords_ratio + 1),
    log(diff.removed_misspellings_ratio + 1),
    log(parent_revision.badwords + 1),
    log(parent_revision.misspellings + 1),
    log(parent_revision.proportion_of_badwords + 1),
    log(parent_revision.proportion_of_misspellings + 1),
    log(revision.badwords + 1),
    log(revision.misspellings + 1),
    log(revision.proportion_of_badwords + 1),
    log(revision.proportion_of_misspellings + 1)
]

wp10 = [
    revision.category_links,
    log(revision.content_chars + 1),
    log(revision.image_links + 1),
    log(revision.cite_templates + 1),
    revision.image_links / max(revision.content_chars, 1),
    revision.infobox_templates,
    revision.infonoise,
    log(revision.internal_links + 1),
    revision.level_2_headings,
    revision.level_3_headings,
    log(revision.ref_tags + 1),
    log(max((revision.ref_tags - revision.cite_templates) + 1, 1)),
    revision.proportion_of_templated_references
]
